#!/bin/bash
# Copyright (C) 2008 - 2011 vortexbox.org
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# Changelog
#
# Tues May 10 2011 Ron Olsen <ronolsen@comcast.net>
# * Use /opt/vortexbox/get-cddevice to get the CDDEVICE.

function echolog {
echo "`date +'%m/%d/%Y %H:%M:%S'` - $1"
}
echo "" >> /var/log/cdrip.log

CDDEVICE=`/opt/vortexbox/get-cddevice`

echolog "<b>Restarting Auto Ripper...</b>" >> /var/log/cdrip.log
echolog "Ripping from $CDDEVICE" >> /var/log/cdrip.log
echolog "`/usr/bin/cd-info -C $CDDEVICE --no-cddb --no-analyze --no-tracks | grep Vendor`" >> /var/log/cdrip.log
echolog "`/usr/bin/cd-info -C $CDDEVICE --no-cddb --no-analyze --no-tracks | grep Model`" >> /var/log/cdrip.log
echolog "`/usr/bin/cd-info -C $CDDEVICE --no-cddb --no-analyze --no-tracks | grep Revision`" >> /var/log/cdrip.log

echo "" >> /var/log/cdrip.log

if ping -c 1 -w 5 "google.com" &>/dev/null ; then
	echolog "Using your Internet connection to get metadata for ripped disks." >> /var/log/cdrip.log
else
	echolog "<b>Internet not avalible.</b> No track or disk info will be avalible." >> /var/log/cdrip.log
	echolog "(Your DNS may not be working)" >> /var/log/cdrip.log
fi	

echo "" >> /var/log/cdrip.log

while true
do
CDSTATUS=`/opt/vortexbox/checkcd $CDDEVICE`
############################################################################
# Rip CDs
# Rip CDs using ripit
############################################################################
 if [ "$CDSTATUS" = "ready" ]; then
   CDINFO=`/usr/bin/cd-info -C $CDDEVICE --no-cddb --no-analyze --no-device-info --no-tracks | grep "Disc mode is listed as" | cut -d \: -f 2`
   CDTYPE=${CDINFO/ /}

   # If the disk is an audio CD rip using ripit
   if [ "$CDTYPE" = "CD-DA" ]; then
     echolog "Optical disk detected - type : Audio CD" >> /var/log/cdrip.log
	 /usr/bin/ripit -d $CDDEVICE
	 /usr/bin/eject $CDDEVICE
	 /opt/vortexbox/checkcd $CDDEVICE
   fi

############################################################################
# Rip DVDs or DVD-A
# Rip DVDs using makemkv
# Rip DVD audio disks using dvdae
############################################################################
   if [ "$CDTYPE" = "DVD-ROM" ]; then

	 if [ ! -f /usr/bin/ffmpeg ]; then
		echolog "Installing (required) ffmpg ..." >> /var/log/cdrip.log
		/usr/local/sbin/setup-mplayer >> /var/log/cdrip.log
	 fi
# Check to see if its a DVD or DVDa
	 HASH=`date +%s%N`
	 mkdir -p /tmp/dvdid$HASH
	 mount $CDDEVICE /tmp/dvdid$HASH &> /dev/null
	 if [ -f "/tmp/dvdid$HASH/AUDIO_TS/AUDIO_TS.IFO" ]; then
	   DVDANAME=`/usr/bin/volname $CDDEVICE | sed 's/ *$//g'`

       echolog "Optical disk detected - type : DVD-A (DVD audio)" >> /var/log/cdrip.log
	   echolog "Ripping $DVDANAME..."  >> /var/log/cdrip.log
	   
	   if [ ! -f /usr/bin/dvdae ]; then
		echolog "Installing (required) dvdae ..." >> /var/log/cdrip.log
		yum clean all
		yum -y install dvdae >> /var/log/cdrip.log
	   fi
	   
	   mkdir -p /storage/music/wav/$DVDANAME
	   /usr/bin/dvdae --format=wav -c2 -b24 --output=/storage/music/wav/$DVDANAME /tmp/dvdid$HASH >> /var/log/cdrip.log 2>&1
	   umount /tmp/dvdid$HASH
	   rm -rf /tmp/dvdid$HASH
	   
	   mkdir -p /storage/music/flac/$DVDANAME
	   cd /storage/music/wav/$DVDANAME
	   TRACK=0
	   for f in *.wav
	    do
		 TRACK=$(($TRACK+1))
		 TRACK=$(printf "%.2d" "$TRACK")
		 echolog "Converting $f to FLAC..."  >> /var/log/cdrip.log
		 OUT="/storage/music/flac/$DVDANAME/$TRACK $DVDANAME.flac"
		 IN="$f"
		 /usr/bin/flac --tag=TRACKNUMBER=$TRACK -f -o "$OUT" "$IN"
		done
		cd ..
		rm -rf /storage/music/wav/$DVDANAME 
	 else	 
	   umount /tmp/dvdid$HASH
	   rm -rf /tmp/dvdid$HASH
	   echolog "Optical disk detected - type : DVD" >> /var/log/cdrip.log
	   /usr/bin/php /opt/vortexbox/docd_helper.php >> /var/log/cdrip.log
	 fi

	 /usr/bin/eject $CDDEVICE
	 /opt/vortexbox/checkcd $CDDEVICE
	 echolog "Done." >> /var/log/cdrip.log
   fi
   
############################################################################
# Rip Blu-ray
# Rip Blu-ray using makemkv
############################################################################
   if [ "$CDTYPE" = "CD-DATA (Mode 1)" ]; then
     echolog "Optical disk detected - type : Blu-ray" >> /var/log/cdrip.log

	 if [ ! -f /usr/bin/ffmpeg ]; then
		echolog "Installing (required) ffmpg ..." >> /var/log/cdrip.log
		/usr/local/sbin/setup-mplayer >> /var/log/cdrip.log
	 fi

	 /usr/bin/php /opt/vortexbox/docd_helper.php >> /var/log/cdrip.log

	 /usr/bin/eject $CDDEVICE
	 /opt/vortexbox/checkcd $CDDEVICE
	 echolog "Done." >> /var/log/cdrip.log
   fi   
 fi

/opt/vortexbox/checkcd $CDDEVICE
 
sleep 2

done
